
.. image:: https://travis-ci.org/datakortet/ttcal.svg?branch=master
    :target: https://travis-ci.org/datakortet/ttcal

.. image:: https://coveralls.io/repos/github/datakortet/ttcal/badge.svg?branch=master
    :target: https://coveralls.io/github/datakortet/ttcal


ttcal - calendar calculations
=============================================================


Installing from PyPI
--------------------

This is what you want if you just want to use ttcal:

   pip install ttcal


As a source package
-------------------

This is what you want if you are developing ttcal or want 
to make local changes to the source code.

   pip install -e <path>


See docs/ folder for documentation.
